.. _tutorials-flaskgreen:

===============
Green Flask
===============

The code for this example is located in the :mod:`examples.flaskgreen.manage`
module.

.. automodule:: examples.flaskgreen.manage
